
import requests
from lxml import etree
import prettytable as pt


class Abbrev:

    def __init__(self):
        self.base_url = 'https://www.allacronyms.com/'
        self.headers = {
            'content-type': 'application/json',
            'User-Agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:22.0) Gecko/20100101 Firefox/22.0'
        }

    def get_abbreviation(self, query: str, verbose: bool, best: bool) -> list:

        url = self.base_url + '_'.join(query.lower().split(' ')) + '/abbreviated'

        try:
            html = requests.get(url=url, headers=self.headers).text
        except Exception as e:
            print(f'fail to connect to < {url} > . {e}')
            return []

        items = self.parse(html, url)

        if verbose:
            table = pt.PrettyTable()
            table.field_names = ["rating", "abbreviation", "item", "tags", ]
            for item in items:
                table.add_row(item)
            print(f'Abbreviation for \'{query}\': \n{len(items)} possible ways to abbreviate \'{query}\'.')
            print(table)

        if not best:
            return items
        else:
            return items[0][1]

    def get_fullname(self, query: str, verbose: bool) -> list:

        if ' ' in query:
            assert 'query shouldn\'t contains any blank space .'
        url = self.base_url + query.upper()

        try:
            html = requests.get(url=url, headers=self.headers).text
        except Exception as e:
            print(f'fail to connect to < {url} > . {e}')
            return []

        items = self.parse(html, url)

        if verbose:
            table = pt.PrettyTable()
            table.field_names = ["rating", "item", "fullname", "tags", ]
            for item in items:
                table.add_row(item)
            print(f'Fullname for \'{query}\': \n{len(items)} possible ways to abbreviated \'{query}\'.')
            print(table)

        return items

    @staticmethod
    def parse(html, url):

        try:
            elements = etree.HTML(html)
            terms_rating = [eval(element.xpath('string()').replace('\n', '').strip()) for element in elements.xpath(
                "//div[@id='main-content']/div[@class='terms']/"
                "div[@class='terms_rating']/div[@class='terms_row term_rating sdRating']")]
            item_container, item_text, items_tags = [], [], []
            for element in elements.xpath(
                    "//div[@id='main-content']/div[@class='terms']"
                    "/div[@class='terms_items']//tr[@class='terms_row']"):
                item_container.append(element.xpath('td')[0].xpath(
                    "string()").replace('\n', '').strip().replace('&period;', '.'))
                item_text.append(
                    element.xpath('td')[1].xpath(
                        "string(div/div[@class='item_text'])"
                    ).replace('\n', '').strip().replace('&comma;', ','))
                items_tags.append(
                    element.xpath('td')[1].xpath(
                        "string(div/div[@class='items_tags'])"
                    ).replace('\n', '').strip())
        except Exception as e:
            print(f'fail to parse elements in web pages < {url} > . {e}')
            return []
        items = list(zip(terms_rating, item_container, item_text, items_tags))

        return items


if __name__ == '__main__':

    # given a fullname string, return it's abbreviation
    print(Abbrev().get_abbreviation('china', verbose=True))

    # given a abbreviation string, return it's fullname
    print(Abbrev().get_fullname('china', verbose=True))





import http.client
import hashlib
import urllib
import random
import json


class Trans:
    def __init__(self):
        self.app_id = None
        self.secret_key = None
        self.url = '/api/trans/vip/translate'

    def add_app_id(self, app_id):
        self.app_id = app_id

    def add_secret_key(self, secret_key):
        self.secret_key = secret_key

    def translate(self, query='', from_lang='auto', to_lang='zh'):

        assert self.app_id is not None and self.secret_key is not None, \
            'please add app id using \'add_app_id\' and add secret key using \'add_secret_key\''

        salt = random.randint(32768, 65536)
        sign = self.app_id + query + str(salt) + self.secret_key
        sign = hashlib.md5(sign.encode()).hexdigest()

        url = self.url + '?appid=' + self.app_id + '&q=' + urllib.parse.quote(
            query) + '&from=' + from_lang + '&to=' + to_lang + '&salt=' + str(
            salt) + '&sign=' + sign

        result, http_client = None, None

        try:
            http_client = http.client.HTTPConnection('api.fanyi.baidu.com')
            http_client.request('GET', url)
            response = http_client.getresponse()
            result_all = response.read().decode("utf-8")
            result = json.loads(result_all)
        except Exception as e:
            print(e)
        finally:
            if http_client:
                http_client.close()

        return result




import setuptools


long_description = """
自然语言处理小工具
"""


setuptools.setup(
    name='dandanlemuria',
    version='0.0.1',
    description='A toolkit for natural language processing',
    long_description=long_description,
    author='dandanlemuria',
    author_email='18110980003@fudan.edu.cn',
    url='https://github.com/LemuriaChen/dandanlemuria',
    license="MIT",
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Indexing',
        'Topic :: Text Processing :: Linguistic',
      ],
    keywords='NLP, toolkit',
    packages=setuptools.find_packages(),
)

